# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from . import utilities, tables

class GetSpotMarketPriceResult:
    """
    A collection of values returned by getSpotMarketPrice.
    """
    def __init__(__self__, price=None, id=None):
        if price and not isinstance(price, float):
            raise TypeError('Expected argument price to be a float')
        __self__.price = price
        """
        Current spot market price for given plan in given facility.
        """
        if id and not isinstance(id, str):
            raise TypeError('Expected argument id to be a str')
        __self__.id = id
        """
        id is the provider-assigned unique ID for this managed resource.
        """

async def get_spot_market_price(facility=None,plan=None,opts=None):
    """
    Use this data source to get Packet Spot Market Price.
    """
    __args__ = dict()

    __args__['facility'] = facility
    __args__['plan'] = plan
    __ret__ = await pulumi.runtime.invoke('packet:index/getSpotMarketPrice:getSpotMarketPrice', __args__, opts=opts)

    return GetSpotMarketPriceResult(
        price=__ret__.get('price'),
        id=__ret__.get('id'))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

_SNAKE_TO_CAMEL_CASE_TABLE = {
    "access_private_ipv4": "accessPrivateIpv4",
    "access_public_ipv4": "accessPublicIpv4",
    "access_public_ipv6": "accessPublicIpv6",
    "address_family": "addressFamily",
    "always_pxe": "alwaysPxe",
    "auth_token": "authToken",
    "bgp_config": "bgpConfig",
    "billing_cycle": "billingCycle",
    "cidr_notation": "cidrNotation",
    "device_id": "deviceId",
    "devices_max": "devicesMax",
    "devices_min": "devicesMin",
    "global_": "global",
    "hardware_reservation_id": "hardwareReservationId",
    "instance_parameters": "instanceParameters",
    "ipxe_script_url": "ipxeScriptUrl",
    "max_bid_price": "maxBidPrice",
    "operating_system": "operatingSystem",
    "organization_id": "organizationId",
    "payment_method_id": "paymentMethodId",
    "project_id": "projectId",
    "project_ssh_key_ids": "projectSshKeyIds",
    "public_ipv4_subnet_size": "publicIpv4SubnetSize",
    "public_key": "publicKey",
    "root_password": "rootPassword",
    "snapshot_policies": "snapshotPolicies",
    "ssh_key_ids": "sshKeyIds",
    "user_data": "userData",
    "volume_id": "volumeId",
    "wait_for_devices": "waitForDevices",
}

_CAMEL_TO_SNAKE_CASE_TABLE = {
    "accessPrivateIpv4": "access_private_ipv4",
    "accessPublicIpv4": "access_public_ipv4",
    "accessPublicIpv6": "access_public_ipv6",
    "addressFamily": "address_family",
    "alwaysPxe": "always_pxe",
    "authToken": "auth_token",
    "bgpConfig": "bgp_config",
    "billingCycle": "billing_cycle",
    "cidrNotation": "cidr_notation",
    "deviceId": "device_id",
    "devicesMax": "devices_max",
    "devicesMin": "devices_min",
    "global": "global_",
    "hardwareReservationId": "hardware_reservation_id",
    "instanceParameters": "instance_parameters",
    "ipxeScriptUrl": "ipxe_script_url",
    "maxBidPrice": "max_bid_price",
    "operatingSystem": "operating_system",
    "organizationId": "organization_id",
    "paymentMethodId": "payment_method_id",
    "projectId": "project_id",
    "projectSshKeyIds": "project_ssh_key_ids",
    "publicIpv4SubnetSize": "public_ipv4_subnet_size",
    "publicKey": "public_key",
    "rootPassword": "root_password",
    "snapshotPolicies": "snapshot_policies",
    "sshKeyIds": "ssh_key_ids",
    "userData": "user_data",
    "volumeId": "volume_id",
    "waitForDevices": "wait_for_devices",
}



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from . import utilities, tables

class Organization(pulumi.CustomResource):
    created: pulumi.Output[str]
    description: pulumi.Output[str]
    """
    Description string.
    """
    logo: pulumi.Output[str]
    """
    Logo URL.
    """
    name: pulumi.Output[str]
    """
    The name of the Organization.
    """
    twitter: pulumi.Output[str]
    """
    Twitter handle.
    """
    updated: pulumi.Output[str]
    website: pulumi.Output[str]
    """
    Website link.
    """
    def __init__(__self__, resource_name, opts=None, description=None, logo=None, name=None, twitter=None, website=None, __name__=None, __opts__=None):
        """
        Provides a resource to manage organization resource in Packet.
        
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] description: Description string.
        :param pulumi.Input[str] logo: Logo URL.
        :param pulumi.Input[str] name: The name of the Organization.
        :param pulumi.Input[str] twitter: Twitter handle.
        :param pulumi.Input[str] website: Website link.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if not resource_name:
            raise TypeError('Missing resource name argument (for URN creation)')
        if not isinstance(resource_name, str):
            raise TypeError('Expected resource name to be a string')
        if opts and not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')

        __props__ = dict()

        __props__['description'] = description

        __props__['logo'] = logo

        if name is None:
            raise TypeError('Missing required property name')
        __props__['name'] = name

        __props__['twitter'] = twitter

        __props__['website'] = website

        __props__['created'] = None
        __props__['updated'] = None

        super(Organization, __self__).__init__(
            'packet:index/organization:Organization',
            resource_name,
            __props__,
            opts)


    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from . import utilities, tables

class GetOperatingSystemResult:
    """
    A collection of values returned by getOperatingSystem.
    """
    def __init__(__self__, slug=None, id=None):
        if slug and not isinstance(slug, str):
            raise TypeError('Expected argument slug to be a str')
        __self__.slug = slug
        """
        Operating system slug (same as `id`)
        """
        if id and not isinstance(id, str):
            raise TypeError('Expected argument id to be a str')
        __self__.id = id
        """
        id is the provider-assigned unique ID for this managed resource.
        """

async def get_operating_system(distro=None,name=None,provisionable_on=None,version=None,opts=None):
    """
    Use this data source to get Packet Operating System image.
    """
    __args__ = dict()

    __args__['distro'] = distro
    __args__['name'] = name
    __args__['provisionableOn'] = provisionable_on
    __args__['version'] = version
    __ret__ = await pulumi.runtime.invoke('packet:index/getOperatingSystem:getOperatingSystem', __args__, opts=opts)

    return GetOperatingSystemResult(
        slug=__ret__.get('slug'),
        id=__ret__.get('id'))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from . import utilities, tables

class ProjectSshKey(pulumi.CustomResource):
    created: pulumi.Output[str]
    """
    The timestamp for when the SSH key was created
    """
    fingerprint: pulumi.Output[str]
    """
    The fingerprint of the SSH key
    """
    name: pulumi.Output[str]
    """
    The name of the SSH key for identification
    """
    project_id: pulumi.Output[str]
    """
    The ID of parent project
    """
    public_key: pulumi.Output[str]
    """
    The public key. If this is a file, it can be read using the file interpolation function
    """
    updated: pulumi.Output[str]
    """
    The timestamp for the last time the SSH key was updated
    """
    def __init__(__self__, resource_name, opts=None, name=None, project_id=None, public_key=None, __name__=None, __opts__=None):
        """
        Provides a Packet project SSH key resource to manage project-specific SSH keys. On contrary to user SSH keys, project SSH keys are used to exclusively populate `authorized_keys` in new devices.
        
        If you supply a list of project SSH keys when creating a new device, only the listed keys are used; user SSH keys are ignored.
        
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] name: The name of the SSH key for identification
        :param pulumi.Input[str] project_id: The ID of parent project
        :param pulumi.Input[str] public_key: The public key. If this is a file, it can be read using the file interpolation function
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if not resource_name:
            raise TypeError('Missing resource name argument (for URN creation)')
        if not isinstance(resource_name, str):
            raise TypeError('Expected resource name to be a string')
        if opts and not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')

        __props__ = dict()

        if name is None:
            raise TypeError('Missing required property name')
        __props__['name'] = name

        if project_id is None:
            raise TypeError('Missing required property project_id')
        __props__['project_id'] = project_id

        if public_key is None:
            raise TypeError('Missing required property public_key')
        __props__['public_key'] = public_key

        __props__['created'] = None
        __props__['fingerprint'] = None
        __props__['updated'] = None

        super(ProjectSshKey, __self__).__init__(
            'packet:index/projectSshKey:ProjectSshKey',
            resource_name,
            __props__,
            opts)


    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

# Make subpackages available:
__all__ = ['config']

# Export this package's modules as members:
from .bgp_session import *
from .device import *
from .ip_attachment import *
from .organization import *
from .project import *
from .project_ssh_key import *
from .reserved_ip_block import *
from .spot_market_request import *
from .ssh_key import *
from .vlan import *
from .volume import *
from .volume_attachment import *
from .get_operating_system import *
from .get_precreated_ip_block import *
from .get_spot_market_price import *
from .provider import *



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***


import os

def get_env(*args):
    for v in args:
        value = os.getenv(v)
        if value is not None:
            return value
    return None

def get_env_bool(*args):
    str = get_env(*args)
    if str is not None:
        # NOTE: these values are taken from https://golang.org/src/strconv/atob.go?s=351:391#L1, which is what
        # Terraform uses internally when parsing boolean values.
        if str in ["1", "t", "T", "true", "TRUE", "True"]:
            return True
        if str in ["0", "f", "F", "false", "FALSE", "False"]:
            return False
    return None

def get_env_int(*args):
    str = get_env(*args)
    if str is not None:
        try:
            return int(str)
        except:
            return None
    return None

def get_env_float(*args):
    str = get_env(*args)
    if str is not None:
        try:
            return float(str)
        except:
            return None
    return None

def require_with_default(req, default):
    try:
        return req()
    except:
        if default is not None:
            return default
        raise



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from . import utilities, tables

class Project(pulumi.CustomResource):
    bgp_config: pulumi.Output[dict]
    """
    Optional BGP settings. Refer to [Packet guide for BGP](https://support.packet.com/kb/articles/bgp).
    """
    created: pulumi.Output[str]
    """
    The timestamp for when the project was created
    """
    name: pulumi.Output[str]
    """
    The name of the project on Packet.net
    """
    organization_id: pulumi.Output[str]
    """
    The UUID of organization under which you want to create the project. If you leave it out, the project will be create under your the default organization of your account.
    """
    payment_method_id: pulumi.Output[str]
    """
    The UUID of payment method for this project. The payment method and the project need to belong to the same organization (passed with `organization_id`, or default).
    """
    updated: pulumi.Output[str]
    """
    The timestamp for the last time the project was updated
    """
    def __init__(__self__, resource_name, opts=None, bgp_config=None, name=None, organization_id=None, payment_method_id=None, __name__=None, __opts__=None):
        """
        Provides a Packet project resource to allow you manage devices
        in your projects.
        
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[dict] bgp_config: Optional BGP settings. Refer to [Packet guide for BGP](https://support.packet.com/kb/articles/bgp).
        :param pulumi.Input[str] name: The name of the project on Packet.net
        :param pulumi.Input[str] organization_id: The UUID of organization under which you want to create the project. If you leave it out, the project will be create under your the default organization of your account.
        :param pulumi.Input[str] payment_method_id: The UUID of payment method for this project. The payment method and the project need to belong to the same organization (passed with `organization_id`, or default).
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if not resource_name:
            raise TypeError('Missing resource name argument (for URN creation)')
        if not isinstance(resource_name, str):
            raise TypeError('Expected resource name to be a string')
        if opts and not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')

        __props__ = dict()

        __props__['bgp_config'] = bgp_config

        if name is None:
            raise TypeError('Missing required property name')
        __props__['name'] = name

        __props__['organization_id'] = organization_id

        __props__['payment_method_id'] = payment_method_id

        __props__['created'] = None
        __props__['updated'] = None

        super(Project, __self__).__init__(
            'packet:index/project:Project',
            resource_name,
            __props__,
            opts)


    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from . import utilities, tables

class ReservedIpBlock(pulumi.CustomResource):
    address: pulumi.Output[str]
    address_family: pulumi.Output[int]
    """
    Address family as integer (4 or 6)
    """
    cidr: pulumi.Output[int]
    """
    length of CIDR prefix of the block as integer
    """
    cidr_notation: pulumi.Output[str]
    """
    Address and mask in CIDR notation, e.g. "147.229.15.30/31"
    """
    facility: pulumi.Output[str]
    """
    Facility where to allocate the public IP address block, makes sense only for type==public_ipv4, must be empty for type==global_ipv4
    """
    gateway: pulumi.Output[str]
    global_: pulumi.Output[bool]
    """
    boolean flag whether addresses from a block are global (i.e. can be assigned in any facility)
    """
    manageable: pulumi.Output[bool]
    management: pulumi.Output[bool]
    netmask: pulumi.Output[str]
    """
    Mask in decimal notation, e.g. "255.255.255.0"
    """
    network: pulumi.Output[str]
    """
    Network IP address portion of the block specification
    """
    project_id: pulumi.Output[str]
    """
    The packet project ID where to allocate the address block
    """
    public: pulumi.Output[bool]
    """
    boolean flag whether addresses from a block are public
    """
    quantity: pulumi.Output[int]
    """
    The number of allocated /32 addresses, a power of 2
    """
    type: pulumi.Output[str]
    """
    Either "global_ipv4" or "public_ipv4", defaults to "public_ipv4" for backward compatibility
    """
    def __init__(__self__, resource_name, opts=None, facility=None, project_id=None, quantity=None, type=None, __name__=None, __opts__=None):
        """
        Provides a resource to create and manage blocks of reserved IP addresses in a project.
        
        When a user provisions first device in a facility, Packet API automatically allocates IPv6/56 and private IPv4/25 blocks.
        The new device then gets IPv6 and private IPv4 addresses from those block. It also gets a public IPv4/31 address.
        Every new device in the project and facility will automatically get IPv6 and private IPv4 addresses from these pre-allocated blocks.
        The IPv6 and private IPv4 blocks can't be created, only imported. With this resource, it's possible to create either public IPv4 blocks or global IPv4 blocks.
        
        Public blocks are allocated in a facility. Addresses from public blocks can only be assigned to devices in the facility. Public blocks can have mask from /24 (256 addresses) to /32 (1 address). If you create public block with this resource, you must fill the facility argmument.
        
        Addresses from global blocks can be assigned in any facility. Global blocks can have mask from /30 (4 addresses), to /32 (1 address). If you create global block with this resource, you must specify type = "global_ipv4" and you must omit the facility argument.
        
        Once IP block is allocated or imported, an address from it can be assigned to device with the `packet_ip_attachment` resource.
        
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] facility: Facility where to allocate the public IP address block, makes sense only for type==public_ipv4, must be empty for type==global_ipv4
        :param pulumi.Input[str] project_id: The packet project ID where to allocate the address block
        :param pulumi.Input[int] quantity: The number of allocated /32 addresses, a power of 2
        :param pulumi.Input[str] type: Either "global_ipv4" or "public_ipv4", defaults to "public_ipv4" for backward compatibility
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if not resource_name:
            raise TypeError('Missing resource name argument (for URN creation)')
        if not isinstance(resource_name, str):
            raise TypeError('Expected resource name to be a string')
        if opts and not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')

        __props__ = dict()

        __props__['facility'] = facility

        if project_id is None:
            raise TypeError('Missing required property project_id')
        __props__['project_id'] = project_id

        if quantity is None:
            raise TypeError('Missing required property quantity')
        __props__['quantity'] = quantity

        __props__['type'] = type

        __props__['address'] = None
        __props__['address_family'] = None
        __props__['cidr'] = None
        __props__['cidr_notation'] = None
        __props__['gateway'] = None
        __props__['global_'] = None
        __props__['manageable'] = None
        __props__['management'] = None
        __props__['netmask'] = None
        __props__['network'] = None
        __props__['public'] = None

        super(ReservedIpBlock, __self__).__init__(
            'packet:index/reservedIpBlock:ReservedIpBlock',
            resource_name,
            __props__,
            opts)


    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from . import utilities, tables

class SshKey(pulumi.CustomResource):
    created: pulumi.Output[str]
    """
    The timestamp for when the SSH key was created
    """
    fingerprint: pulumi.Output[str]
    """
    The fingerprint of the SSH key
    """
    name: pulumi.Output[str]
    """
    The name of the SSH key for identification
    """
    public_key: pulumi.Output[str]
    """
    The public key. If this is a file, it
    can be read using the file interpolation function
    """
    updated: pulumi.Output[str]
    """
    The timestamp for the last time the SSH key was updated
    """
    def __init__(__self__, resource_name, opts=None, name=None, public_key=None, __name__=None, __opts__=None):
        """
        Provides a resource to manage User SSH keys on your Packet user account. If you create a new device in a project, all the keys of the project's collaborators will be injected to the device.
        
        The link between User SSH key and device is implicit. If you want to make sure that a key will be copied to a device, you must ensure that the device resource `depends_on` the key resource.
        
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] name: The name of the SSH key for identification
        :param pulumi.Input[str] public_key: The public key. If this is a file, it
               can be read using the file interpolation function
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if not resource_name:
            raise TypeError('Missing resource name argument (for URN creation)')
        if not isinstance(resource_name, str):
            raise TypeError('Expected resource name to be a string')
        if opts and not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')

        __props__ = dict()

        if name is None:
            raise TypeError('Missing required property name')
        __props__['name'] = name

        if public_key is None:
            raise TypeError('Missing required property public_key')
        __props__['public_key'] = public_key

        __props__['created'] = None
        __props__['fingerprint'] = None
        __props__['updated'] = None

        super(SshKey, __self__).__init__(
            'packet:index/sshKey:SshKey',
            resource_name,
            __props__,
            opts)


    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from . import utilities, tables

class IpAttachment(pulumi.CustomResource):
    address: pulumi.Output[str]
    address_family: pulumi.Output[int]
    """
    Address family as integer (4 or 6)
    """
    cidr: pulumi.Output[int]
    """
    length of CIDR prefix of the subnet as integer
    """
    cidr_notation: pulumi.Output[str]
    """
    CIDR notation of subnet from block reserved in the same
    project and facility as the device
    """
    device_id: pulumi.Output[str]
    """
    ID of device to which to assign the subnet
    """
    gateway: pulumi.Output[str]
    """
    IP address of gateway for the subnet
    """
    global_: pulumi.Output[bool]
    manageable: pulumi.Output[bool]
    management: pulumi.Output[bool]
    netmask: pulumi.Output[str]
    """
    Subnet mask in decimal notation, e.g. "255.255.255.0"
    """
    network: pulumi.Output[str]
    """
    Subnet network address
    """
    public: pulumi.Output[bool]
    """
    boolean flag whether subnet is reachable from the Internet
    """
    def __init__(__self__, resource_name, opts=None, cidr_notation=None, device_id=None, __name__=None, __opts__=None):
        """
        Provides a resource to attach elastic IP subnets to devices.
        
        To attach an IP subnet from a reserved block to a provisioned device, you must derive a subnet CIDR belonging to
        one of your reserved blocks in the same project and facility as the target device.
        
        For example, you have reserved IPv4 address block 147.229.10.152/30, you can choose to assign either the whole
        block as one subnet to a device; or 2 subnets with CIDRs 147.229.10.152/31' and 147.229.10.154/31; or 4 subnets
        with mask prefix length 32. More about the elastic IP subnets is [here](https://help.packet.net/article/54-elastic-ips).
        
        Device and reserved block must be in the same facility.
        
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] cidr_notation: CIDR notation of subnet from block reserved in the same
               project and facility as the device
        :param pulumi.Input[str] device_id: ID of device to which to assign the subnet
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if not resource_name:
            raise TypeError('Missing resource name argument (for URN creation)')
        if not isinstance(resource_name, str):
            raise TypeError('Expected resource name to be a string')
        if opts and not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')

        __props__ = dict()

        if cidr_notation is None:
            raise TypeError('Missing required property cidr_notation')
        __props__['cidr_notation'] = cidr_notation

        if device_id is None:
            raise TypeError('Missing required property device_id')
        __props__['device_id'] = device_id

        __props__['address'] = None
        __props__['address_family'] = None
        __props__['cidr'] = None
        __props__['gateway'] = None
        __props__['global_'] = None
        __props__['manageable'] = None
        __props__['management'] = None
        __props__['netmask'] = None
        __props__['network'] = None
        __props__['public'] = None

        super(IpAttachment, __self__).__init__(
            'packet:index/ipAttachment:IpAttachment',
            resource_name,
            __props__,
            opts)


    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from . import utilities, tables

class VolumeAttachment(pulumi.CustomResource):
    device_id: pulumi.Output[str]
    """
    The ID of the device to which the volume should be attached
    """
    volume_id: pulumi.Output[str]
    """
    The ID of the volume to attach
    """
    def __init__(__self__, resource_name, opts=None, device_id=None, volume_id=None, __name__=None, __opts__=None):
        """
        Provides attachment of Packet Block Storage Volume to Devices.
        
        Device and volume must be in the same location (facility).
        
        Once attached by Terraform, they must then be mounted using the `packet_block_attach` and `packet_block_detach` scripts.
        
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] device_id: The ID of the device to which the volume should be attached
        :param pulumi.Input[str] volume_id: The ID of the volume to attach
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if not resource_name:
            raise TypeError('Missing resource name argument (for URN creation)')
        if not isinstance(resource_name, str):
            raise TypeError('Expected resource name to be a string')
        if opts and not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')

        __props__ = dict()

        if device_id is None:
            raise TypeError('Missing required property device_id')
        __props__['device_id'] = device_id

        if volume_id is None:
            raise TypeError('Missing required property volume_id')
        __props__['volume_id'] = volume_id

        super(VolumeAttachment, __self__).__init__(
            'packet:index/volumeAttachment:VolumeAttachment',
            resource_name,
            __props__,
            opts)


    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from . import utilities, tables

class BgpSession(pulumi.CustomResource):
    address_family: pulumi.Output[str]
    """
    `ipv4` or `ipv6`
    """
    device_id: pulumi.Output[str]
    """
    ID of device 
    """
    status: pulumi.Output[str]
    def __init__(__self__, resource_name, opts=None, address_family=None, device_id=None, __name__=None, __opts__=None):
        """
        Provides a resource to manage BGP sessions in Packet Host. Refer to [Packet BGP documentation](https://support.packet.com/kb/articles/bgp) for more details.
        
        You need to have BGP config enabled in your project.
        
        BGP session must be linked to a device running [BIRD](https://bird.network.cz) or other BGP routing daemon which will control route advertisements via the session to Packet's upstream routers. 
        
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] address_family: `ipv4` or `ipv6`
        :param pulumi.Input[str] device_id: ID of device 
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if not resource_name:
            raise TypeError('Missing resource name argument (for URN creation)')
        if not isinstance(resource_name, str):
            raise TypeError('Expected resource name to be a string')
        if opts and not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')

        __props__ = dict()

        if address_family is None:
            raise TypeError('Missing required property address_family')
        __props__['address_family'] = address_family

        if device_id is None:
            raise TypeError('Missing required property device_id')
        __props__['device_id'] = device_id

        __props__['status'] = None

        super(BgpSession, __self__).__init__(
            'packet:index/bgpSession:BgpSession',
            resource_name,
            __props__,
            opts)


    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from .. import utilities, tables

__config__ = pulumi.Config('packet')

auth_token = utilities.require_with_default(lambda: __config__.require('authToken'), utilities.get_env('PACKET_AUTH_TOKEN'))
"""
The API auth key for API operations.
"""




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from . import utilities, tables

class SpotMarketRequest(pulumi.CustomResource):
    devices_max: pulumi.Output[int]
    """
    Maximum number devices to be created
    """
    devices_min: pulumi.Output[int]
    """
    Miniumum number devices to be created
    """
    facilities: pulumi.Output[list]
    """
    Facility IDs where devices should be created
    """
    instance_parameters: pulumi.Output[dict]
    """
    Device parameters. See device resource for details
    """
    max_bid_price: pulumi.Output[float]
    """
    Maximum price user is willing to pay per hour per device
    """
    project_id: pulumi.Output[str]
    """
    Project ID
    """
    wait_for_devices: pulumi.Output[bool]
    """
    On resource creation - wait until all desired devices are active, on resource destruction - wait until devices are removed
    """
    def __init__(__self__, resource_name, opts=None, devices_max=None, devices_min=None, facilities=None, instance_parameters=None, max_bid_price=None, project_id=None, wait_for_devices=None, __name__=None, __opts__=None):
        """
        Provides a Packet Spot Market Request resource to allow you to
        manage spot market requests on your account. https://help.packet.net/en-us/article/20-spot-market 
        
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[int] devices_max: Maximum number devices to be created
        :param pulumi.Input[int] devices_min: Miniumum number devices to be created
        :param pulumi.Input[list] facilities: Facility IDs where devices should be created
        :param pulumi.Input[dict] instance_parameters: Device parameters. See device resource for details
        :param pulumi.Input[float] max_bid_price: Maximum price user is willing to pay per hour per device
        :param pulumi.Input[str] project_id: Project ID
        :param pulumi.Input[bool] wait_for_devices: On resource creation - wait until all desired devices are active, on resource destruction - wait until devices are removed
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if not resource_name:
            raise TypeError('Missing resource name argument (for URN creation)')
        if not isinstance(resource_name, str):
            raise TypeError('Expected resource name to be a string')
        if opts and not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')

        __props__ = dict()

        if devices_max is None:
            raise TypeError('Missing required property devices_max')
        __props__['devices_max'] = devices_max

        if devices_min is None:
            raise TypeError('Missing required property devices_min')
        __props__['devices_min'] = devices_min

        if facilities is None:
            raise TypeError('Missing required property facilities')
        __props__['facilities'] = facilities

        if instance_parameters is None:
            raise TypeError('Missing required property instance_parameters')
        __props__['instance_parameters'] = instance_parameters

        if max_bid_price is None:
            raise TypeError('Missing required property max_bid_price')
        __props__['max_bid_price'] = max_bid_price

        if project_id is None:
            raise TypeError('Missing required property project_id')
        __props__['project_id'] = project_id

        __props__['wait_for_devices'] = wait_for_devices

        super(SpotMarketRequest, __self__).__init__(
            'packet:index/spotMarketRequest:SpotMarketRequest',
            resource_name,
            __props__,
            opts)


    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from . import utilities, tables

class GetPrecreatedIpBlockResult:
    """
    A collection of values returned by getPrecreatedIpBlock.
    """
    def __init__(__self__, address=None, cidr=None, cidr_notation=None, gateway=None, manageable=None, management=None, netmask=None, network=None, quantity=None, id=None):
        if address and not isinstance(address, str):
            raise TypeError('Expected argument address to be a str')
        __self__.address = address
        if cidr and not isinstance(cidr, int):
            raise TypeError('Expected argument cidr to be a int')
        __self__.cidr = cidr
        if cidr_notation and not isinstance(cidr_notation, str):
            raise TypeError('Expected argument cidr_notation to be a str')
        __self__.cidr_notation = cidr_notation
        """
        CIDR notation of the looked up block.
        """
        if gateway and not isinstance(gateway, str):
            raise TypeError('Expected argument gateway to be a str')
        __self__.gateway = gateway
        if manageable and not isinstance(manageable, bool):
            raise TypeError('Expected argument manageable to be a bool')
        __self__.manageable = manageable
        if management and not isinstance(management, bool):
            raise TypeError('Expected argument management to be a bool')
        __self__.management = management
        if netmask and not isinstance(netmask, str):
            raise TypeError('Expected argument netmask to be a str')
        __self__.netmask = netmask
        if network and not isinstance(network, str):
            raise TypeError('Expected argument network to be a str')
        __self__.network = network
        if quantity and not isinstance(quantity, int):
            raise TypeError('Expected argument quantity to be a int')
        __self__.quantity = quantity
        if id and not isinstance(id, str):
            raise TypeError('Expected argument id to be a str')
        __self__.id = id
        """
        id is the provider-assigned unique ID for this managed resource.
        """

async def get_precreated_ip_block(address_family=None,facility=None,global_=None,project_id=None,public=None,opts=None):
    """
    Use this data source to get CIDR expression for precreated IPv6 and IPv4 blocks in Packet.
    You can then use the cidrsubnet TF builtin function to derive subnets.
    """
    __args__ = dict()

    __args__['addressFamily'] = address_family
    __args__['facility'] = facility
    __args__['global'] = global_
    __args__['projectId'] = project_id
    __args__['public'] = public
    __ret__ = await pulumi.runtime.invoke('packet:index/getPrecreatedIpBlock:getPrecreatedIpBlock', __args__, opts=opts)

    return GetPrecreatedIpBlockResult(
        address=__ret__.get('address'),
        cidr=__ret__.get('cidr'),
        cidr_notation=__ret__.get('cidrNotation'),
        gateway=__ret__.get('gateway'),
        manageable=__ret__.get('manageable'),
        management=__ret__.get('management'),
        netmask=__ret__.get('netmask'),
        network=__ret__.get('network'),
        quantity=__ret__.get('quantity'),
        id=__ret__.get('id'))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from . import utilities, tables

class Device(pulumi.CustomResource):
    access_private_ipv4: pulumi.Output[str]
    """
    The ipv4 private IP assigned to the device
    """
    access_public_ipv4: pulumi.Output[str]
    """
    The ipv4 maintenance IP assigned to the device
    """
    access_public_ipv6: pulumi.Output[str]
    """
    The ipv6 maintenance IP assigned to the device
    """
    always_pxe: pulumi.Output[bool]
    """
    If true, a device with OS `custom_ipxe` will
    continue to boot via iPXE on reboots.
    """
    billing_cycle: pulumi.Output[str]
    """
    monthly or hourly
    """
    created: pulumi.Output[str]
    """
    The timestamp for when the device was created
    """
    description: pulumi.Output[str]
    """
    Description string for the device
    """
    facilities: pulumi.Output[list]
    """
    List of facility codes with deployment preferences. Packet API will go through the list and will deploy your device to first facility with free capacity. List items must be facility codes or `any` (a wildcard). To find the facility code, visit [Facilities API docs](https://www.packet.net/developers/api/#facilities), set your API auth token in the top of the page and see JSON from the API response.
    """
    facility: pulumi.Output[str]
    """
    The facility in which to create the device.
    """
    hardware_reservation_id: pulumi.Output[str]
    """
    The id of hardware reservation where you want this device deployed, or `next-available` if you want to pick your next available reservation automatically.
    """
    hostname: pulumi.Output[str]
    """
    The device name
    """
    ipxe_script_url: pulumi.Output[str]
    """
    URL pointing to a hosted iPXE script. More
    information is in the
    [Custom iPXE](https://help.packet.net/article/26-custom-ipxe)
    doc.
    """
    locked: pulumi.Output[bool]
    """
    Whether the device is locked
    """
    networks: pulumi.Output[list]
    """
    The device's private and public IP (v4 and v6) network details. When a device is run without any special network configuration, it will have 3 networks: 
    * Public IPv4 at `packet_device.name.network.0`
    * IPv6 at `packet_device.name.network.1`
    * Private IPv4 at `packet_device.name.network.2`
    Elastic addresses then stack by type - an assigned public IPv4 will go after the management public IPv4 (to index 1), and will then shift the indices of the IPv6 and private IPv4. Assigned private IPv4 will go after the management private IPv4 (to the end of the network list).
    The fields of the network attributes are:
    """
    operating_system: pulumi.Output[str]
    """
    The operating system slug. To find the slug, or visit [Operating Systems API docs](https://www.packet.net/developers/api/#operatingsystems), set your API auth token in the top of the page and see JSON from the API response.
    """
    plan: pulumi.Output[str]
    """
    The device plan slug. To find the plan slug, visit [Device plans API docs](https://www.packet.net/developers/api/#plans), set your auth token in the top of the page and see JSON from the API response.
    """
    project_id: pulumi.Output[str]
    """
    The id of the project in which to create the device
    """
    project_ssh_key_ids: pulumi.Output[list]
    """
    Array of IDs of the project SSH keys which should be added to the device. If you omit this, SSH keys of all the members of the parent project will be added to the device. If you specify this array, only the listed project SSH keys will be added. Project SSH keys can be created with the [packet_project_ssh_key][packet_project_ssh_key.html] resource.
    """
    public_ipv4_subnet_size: pulumi.Output[int]
    """
    Size of allocated subnet, more
    information is in the
    [Custom Subnet Size](https://help.packet.net/article/55-custom-subnet-size) doc.
    """
    root_password: pulumi.Output[str]
    """
    Root password to the server (disabled after 24 hours)
    """
    ssh_key_ids: pulumi.Output[list]
    """
    List of IDs of SSH keys deployed in the device, can be both user and project SSH keys
    """
    state: pulumi.Output[str]
    """
    The status of the device
    """
    storage: pulumi.Output[str]
    """
    JSON for custom partitioning. Only usable on reserved hardware. More information in in the [Custom Partitioning and RAID](https://help.packet.net/article/61-custom-partitioning-raid) doc.
    """
    tags: pulumi.Output[list]
    """
    Tags attached to the device
    """
    updated: pulumi.Output[str]
    """
    The timestamp for the last time the device was updated
    """
    user_data: pulumi.Output[str]
    """
    A string of the desired User Data for the device.
    """
    def __init__(__self__, resource_name, opts=None, always_pxe=None, billing_cycle=None, description=None, facilities=None, facility=None, hardware_reservation_id=None, hostname=None, ipxe_script_url=None, operating_system=None, plan=None, project_id=None, project_ssh_key_ids=None, public_ipv4_subnet_size=None, storage=None, tags=None, user_data=None, __name__=None, __opts__=None):
        """
        Provides a Packet device resource. This can be used to create,
        modify, and delete devices.
        
        > **Note:** All arguments including the root_password and user_data will be stored in
         the raw state as plain-text.
        [Read more about sensitive data in state](https://www.terraform.io/docs/state/sensitive-data.html).
        
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] always_pxe: If true, a device with OS `custom_ipxe` will
               continue to boot via iPXE on reboots.
        :param pulumi.Input[str] billing_cycle: monthly or hourly
        :param pulumi.Input[str] description: Description string for the device
        :param pulumi.Input[list] facilities: List of facility codes with deployment preferences. Packet API will go through the list and will deploy your device to first facility with free capacity. List items must be facility codes or `any` (a wildcard). To find the facility code, visit [Facilities API docs](https://www.packet.net/developers/api/#facilities), set your API auth token in the top of the page and see JSON from the API response.
        :param pulumi.Input[str] facility: The facility in which to create the device.
        :param pulumi.Input[str] hardware_reservation_id: The id of hardware reservation where you want this device deployed, or `next-available` if you want to pick your next available reservation automatically.
        :param pulumi.Input[str] hostname: The device name
        :param pulumi.Input[str] ipxe_script_url: URL pointing to a hosted iPXE script. More
               information is in the
               [Custom iPXE](https://help.packet.net/article/26-custom-ipxe)
               doc.
        :param pulumi.Input[str] operating_system: The operating system slug. To find the slug, or visit [Operating Systems API docs](https://www.packet.net/developers/api/#operatingsystems), set your API auth token in the top of the page and see JSON from the API response.
        :param pulumi.Input[str] plan: The device plan slug. To find the plan slug, visit [Device plans API docs](https://www.packet.net/developers/api/#plans), set your auth token in the top of the page and see JSON from the API response.
        :param pulumi.Input[str] project_id: The id of the project in which to create the device
        :param pulumi.Input[list] project_ssh_key_ids: Array of IDs of the project SSH keys which should be added to the device. If you omit this, SSH keys of all the members of the parent project will be added to the device. If you specify this array, only the listed project SSH keys will be added. Project SSH keys can be created with the [packet_project_ssh_key][packet_project_ssh_key.html] resource.
        :param pulumi.Input[int] public_ipv4_subnet_size: Size of allocated subnet, more
               information is in the
               [Custom Subnet Size](https://help.packet.net/article/55-custom-subnet-size) doc.
        :param pulumi.Input[str] storage: JSON for custom partitioning. Only usable on reserved hardware. More information in in the [Custom Partitioning and RAID](https://help.packet.net/article/61-custom-partitioning-raid) doc.
        :param pulumi.Input[list] tags: Tags attached to the device
        :param pulumi.Input[str] user_data: A string of the desired User Data for the device.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if not resource_name:
            raise TypeError('Missing resource name argument (for URN creation)')
        if not isinstance(resource_name, str):
            raise TypeError('Expected resource name to be a string')
        if opts and not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')

        __props__ = dict()

        __props__['always_pxe'] = always_pxe

        if billing_cycle is None:
            raise TypeError('Missing required property billing_cycle')
        __props__['billing_cycle'] = billing_cycle

        __props__['description'] = description

        __props__['facilities'] = facilities

        __props__['facility'] = facility

        __props__['hardware_reservation_id'] = hardware_reservation_id

        if hostname is None:
            raise TypeError('Missing required property hostname')
        __props__['hostname'] = hostname

        __props__['ipxe_script_url'] = ipxe_script_url

        if operating_system is None:
            raise TypeError('Missing required property operating_system')
        __props__['operating_system'] = operating_system

        if plan is None:
            raise TypeError('Missing required property plan')
        __props__['plan'] = plan

        if project_id is None:
            raise TypeError('Missing required property project_id')
        __props__['project_id'] = project_id

        __props__['project_ssh_key_ids'] = project_ssh_key_ids

        __props__['public_ipv4_subnet_size'] = public_ipv4_subnet_size

        __props__['storage'] = storage

        __props__['tags'] = tags

        __props__['user_data'] = user_data

        __props__['access_private_ipv4'] = None
        __props__['access_public_ipv4'] = None
        __props__['access_public_ipv6'] = None
        __props__['created'] = None
        __props__['locked'] = None
        __props__['networks'] = None
        __props__['root_password'] = None
        __props__['ssh_key_ids'] = None
        __props__['state'] = None
        __props__['updated'] = None

        super(Device, __self__).__init__(
            'packet:index/device:Device',
            resource_name,
            __props__,
            opts)


    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from . import utilities, tables

class Vlan(pulumi.CustomResource):
    description: pulumi.Output[str]
    """
    Description string
    """
    facility: pulumi.Output[str]
    """
    Facility where to create the VLAN
    """
    project_id: pulumi.Output[str]
    """
    ID of parent project
    """
    vxlan: pulumi.Output[int]
    """
    VXLAN segment ID
    """
    def __init__(__self__, resource_name, opts=None, description=None, facility=None, project_id=None, __name__=None, __opts__=None):
        """
        Provides a resource to allow users to manage Virtual Networks in their projects. VLANs are used in [Layer 2 networking setup](https://packet.kayako.com/article/57-layer-2-overview).
        
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] description: Description string
        :param pulumi.Input[str] facility: Facility where to create the VLAN
        :param pulumi.Input[str] project_id: ID of parent project
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if not resource_name:
            raise TypeError('Missing resource name argument (for URN creation)')
        if not isinstance(resource_name, str):
            raise TypeError('Expected resource name to be a string')
        if opts and not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')

        __props__ = dict()

        __props__['description'] = description

        if facility is None:
            raise TypeError('Missing required property facility')
        __props__['facility'] = facility

        if project_id is None:
            raise TypeError('Missing required property project_id')
        __props__['project_id'] = project_id

        __props__['vxlan'] = None

        super(Vlan, __self__).__init__(
            'packet:index/vlan:Vlan',
            resource_name,
            __props__,
            opts)


    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from . import utilities, tables

class Volume(pulumi.CustomResource):
    attachments: pulumi.Output[list]
    """
    A list of attachments, each with it's own `href` attribute
    """
    billing_cycle: pulumi.Output[str]
    """
    The billing cycle, defaults to "hourly"
    """
    created: pulumi.Output[str]
    """
    The timestamp for when the volume was created
    """
    description: pulumi.Output[str]
    """
    Optional description for the volume
    """
    facility: pulumi.Output[str]
    """
    The facility to create the volume in
    """
    locked: pulumi.Output[bool]
    """
    Lock or unlock the volume
    """
    name: pulumi.Output[str]
    """
    The name of the volume
    """
    plan: pulumi.Output[str]
    """
    The service plan slug of the volume
    """
    project_id: pulumi.Output[str]
    """
    The packet project ID to deploy the volume in
    """
    size: pulumi.Output[int]
    """
    The size in GB to make the volume
    """
    snapshot_policies: pulumi.Output[list]
    """
    Optional list of snapshot policies
    """
    state: pulumi.Output[str]
    """
    The state of the volume
    """
    updated: pulumi.Output[str]
    """
    The timestamp for the last time the volume was updated
    """
    def __init__(__self__, resource_name, opts=None, billing_cycle=None, description=None, facility=None, locked=None, plan=None, project_id=None, size=None, snapshot_policies=None, __name__=None, __opts__=None):
        """
        Provides a Packet Block Storage Volume resource to allow you to
        manage block volumes on your account.
        Once created by Terraform, they must then be attached and mounted
        using the api and `packet_block_attach` and `packet_block_detach`
        scripts.
        
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] billing_cycle: The billing cycle, defaults to "hourly"
        :param pulumi.Input[str] description: Optional description for the volume
        :param pulumi.Input[str] facility: The facility to create the volume in
        :param pulumi.Input[bool] locked: Lock or unlock the volume
        :param pulumi.Input[str] plan: The service plan slug of the volume
        :param pulumi.Input[str] project_id: The packet project ID to deploy the volume in
        :param pulumi.Input[int] size: The size in GB to make the volume
        :param pulumi.Input[list] snapshot_policies: Optional list of snapshot policies
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if not resource_name:
            raise TypeError('Missing resource name argument (for URN creation)')
        if not isinstance(resource_name, str):
            raise TypeError('Expected resource name to be a string')
        if opts and not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')

        __props__ = dict()

        __props__['billing_cycle'] = billing_cycle

        __props__['description'] = description

        if facility is None:
            raise TypeError('Missing required property facility')
        __props__['facility'] = facility

        __props__['locked'] = locked

        if plan is None:
            raise TypeError('Missing required property plan')
        __props__['plan'] = plan

        if project_id is None:
            raise TypeError('Missing required property project_id')
        __props__['project_id'] = project_id

        if size is None:
            raise TypeError('Missing required property size')
        __props__['size'] = size

        __props__['snapshot_policies'] = snapshot_policies

        __props__['attachments'] = None
        __props__['created'] = None
        __props__['name'] = None
        __props__['state'] = None
        __props__['updated'] = None

        super(Volume, __self__).__init__(
            'packet:index/volume:Volume',
            resource_name,
            __props__,
            opts)


    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop

